Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CHYLE ¶
type CHYLE struct {
FEATURES struct {
MATCHERS matchers.Features
EXTRACTORS extractors.Features
DECORATORS decorators.Features
SENDERS senders.Features
} `json:"-"`
GIT struct {
REPOSITORY struct {
PATH string
}
REFERENCE struct {
FROM string
TO string
}
}
MATCHERS matchers.Config
EXTRACTORS extractors.Config
DECORATORS decorators.Config
SENDERS senders.Config
}
CHYLE hold config extracted from environment variables
type EnvValidationError ¶ added in v1.1.0
type EnvValidationError struct {
// contains filtered or unexported fields
}
EnvValidationError is called when validating a configuration failed, it keeps a track of which environment variable is actually tested
func (EnvValidationError) Env ¶ added in v1.1.0
func (v EnvValidationError) Env() string
Env returns environment variable currently tested
func (EnvValidationError) Error ¶ added in v1.1.0
func (v EnvValidationError) Error() string
Error returns error as string
type MissingEnvError ¶ added in v1.1.0
type MissingEnvError struct {
// contains filtered or unexported fields
}
MissingEnvError is called when one or several environment variables are missing
func (MissingEnvError) Envs ¶ added in v1.1.0
func (e MissingEnvError) Envs() []string
Envs returns environment variables missing
func (MissingEnvError) Error ¶ added in v1.1.0
func (e MissingEnvError) Error() string
Errors returns error as string
Click to show internal directories.
Click to hide internal directories.